# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.models.update_transaction_request import UpdateTransactionRequest

class TestUpdateTransactionRequest(unittest.TestCase):
    """UpdateTransactionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateTransactionRequest:
        """Test UpdateTransactionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateTransactionRequest`
        """
        model = UpdateTransactionRequest()
        if include_optional:
            return UpdateTransactionRequest(
                id = 1,
                description = '',
                var_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                paid = True,
                amount_cents = -2147483647,
                total_installments = 1,
                installment = 1,
                recurring = True,
                account_id = 1,
                account_type = 'Account',
                category_id = 1,
                notes = '',
                attachments_count = 0,
                credit_card_id = 1,
                credit_card_invoice_id = 1,
                paid_credit_card_id = 1,
                paid_credit_card_invoice_id = 1,
                oposite_transaction_id = 1,
                oposite_account_id = 1,
                created_at = '-8072i_0408 20012345678910111213141516171819',
                updated_at = '-8072i_0408 20012345678910111213141516171819',
                tags = [
                    ''
                    ],
                attachments = [
                    ''
                    ],
                update_future = True,
                update_all = True
            )
        else:
            return UpdateTransactionRequest(
        )
        """

    def testUpdateTransactionRequest(self):
        """Test UpdateTransactionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
