# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.api.credit_cards_api import CreditCardsApi


class TestCreditCardsApi(unittest.TestCase):
    """CreditCardsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CreditCardsApi()

    def tearDown(self) -> None:
        pass

    def test_create_credit_card(self) -> None:
        """Test case for create_credit_card

        Create Credit Card
        """
        pass

    def test_delete_credit_card(self) -> None:
        """Test case for delete_credit_card

        Delete Credit Card
        """
        pass

    def test_list_credit_card_invoice_payments(self) -> None:
        """Test case for list_credit_card_invoice_payments

        List Credit Card Invoice Payments
        """
        pass

    def test_list_credit_card_invoices(self) -> None:
        """Test case for list_credit_card_invoices

        List Credit Card Invoices
        """
        pass

    def test_list_credit_cards(self) -> None:
        """Test case for list_credit_cards

        List Credit Cards
        """
        pass

    def test_read_credit_card(self) -> None:
        """Test case for read_credit_card

        Read Credit Card
        """
        pass

    def test_read_credit_card_invoice(self) -> None:
        """Test case for read_credit_card_invoice

        Read Credit Card Invoice
        """
        pass

    def test_update_credit_card(self) -> None:
        """Test case for update_credit_card

        Update Credit Card
        """
        pass


if __name__ == '__main__':
    unittest.main()
