# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.api.bank_accounts_api import BankAccountsApi


class TestBankAccountsApi(unittest.TestCase):
    """BankAccountsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BankAccountsApi()

    def tearDown(self) -> None:
        pass

    def test_create_bank_account(self) -> None:
        """Test case for create_bank_account

        Create Bank Account
        """
        pass

    def test_delete_bank_account(self) -> None:
        """Test case for delete_bank_account

        Delete Bank Account
        """
        pass

    def test_list_bank_accounts(self) -> None:
        """Test case for list_bank_accounts

        List Bank Accounts
        """
        pass

    def test_read_bank_account(self) -> None:
        """Test case for read_bank_account

        Read Account
        """
        pass

    def test_update_bank_account(self) -> None:
        """Test case for update_bank_account

        Update Bank Account
        """
        pass


if __name__ == '__main__':
    unittest.main()
