# coding: utf-8

"""
Organizze API

Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from setuptools import setup, find_packages  # noqa: H301
from pathlib import Path

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools


# Read version from pyproject.toml (compatible with Python 3.9+)
def get_version():
    """Read version from pyproject.toml without requiring tomllib"""
    pyproject_path = Path(__file__).parent / "pyproject.toml"
    with open(pyproject_path, "r") as f:
        for line in f:
            if line.startswith("version ="):
                return line.split("=")[1].strip().strip('"').strip("'")
    return "0.0.0"


NAME = "organizze_api"
VERSION = get_version()
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="SDK to interface with the Organizze REST API",
    author="Rhuan Barreto",
    author_email="rhuan@barreto.work",
    url="https://pypi.org/project/organizze_api/",
    keywords=["OpenAPI", "OpenAPI-Generator", "Organizze API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache-2.0",
    long_description_content_type="text/markdown",
    long_description="""\
    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)
    """,  # noqa: E501
    package_data={"organizze_api": ["py.typed"]},
)
