# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.api.categories_api import CategoriesApi


class TestCategoriesApi(unittest.TestCase):
    """CategoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CategoriesApi()

    def tearDown(self) -> None:
        pass

    def test_create_category(self) -> None:
        """Test case for create_category

        Create Category
        """
        pass

    def test_delete_category(self) -> None:
        """Test case for delete_category

        Delete Category
        """
        pass

    def test_list_categories(self) -> None:
        """Test case for list_categories

        List Categories
        """
        pass

    def test_read_category(self) -> None:
        """Test case for read_category

        Read Category
        """
        pass

    def test_update_category(self) -> None:
        """Test case for update_category

        Update Category
        """
        pass


if __name__ == '__main__':
    unittest.main()
